@@ -17,10 +17,6 @@
 # You should have received a copy of the GNU General Public License
 # along with Rcpp.  If not, see <http://www.gnu.org/licenses/>.
 
-.setUp <- function(){
-    suppressMessages( require( inline ) )
-}
-
 test.RcppMatrix.int <- function() {
     src <- 'RcppMatrix<int> m(x);
             RcppResultSet rs;
@@ -32,7 +28,7 @@ test.RcppMatrix.int <- function() {
             std::vector<std::vector<int> > mm = m.stlMatrix();
             rs.add("m",     mm);
 	    return rs.getReturnList();';
-    funx <- cfunction(signature(x="numeric"), src, Rcpp=TRUE)
+    funx <- cppfunction(signature(x="numeric"), src)
     M <- matrix(1:6,2,3,byrow=TRUE)
     checkEquals(funx(x=M), list(dim1=2, dim2=3, rows=2, cols=3, p22=5, m=M),
                      msg = "RcppMatrix.int")
@@ -49,7 +45,7 @@ test.RcppMatrix.double <- function() {
             std::vector<std::vector<double> > mm = m.stlMatrix();
             rs.add("m",     mm);
 	    return rs.getReturnList();';
-    funx <- cfunction(signature(x="numeric"), src, Rcpp=TRUE)
+    funx <- cppfunction(signature(x="numeric"), src)
     M <- matrix(1:6,2,3,byrow=TRUE)
     checkEquals(funx(x=M), list(dim1=2, dim2=3, rows=2, cols=3, p22=5, m=M),
                      msg = "RcppMatrix.double")
@@ -63,7 +59,7 @@ test.RcppMatrix.double.na.nan <- function() {
             rs.add("nan_31", R_IsNaN(m(2,0)));
             rs.add("nan_32", R_IsNaN(m(2,1)));
 	    return rs.getReturnList();';
-    funx <- cfunction(signature(x="numeric"), src, Rcpp=TRUE)
+    funx <- cppfunction(signature(x="numeric"), src)
     M <- matrix(1:6,3,2,byrow=TRUE)
     M[2,1] <- NA
     M[3,1] <- NaN
