@@ -23,6 +23,7 @@
 
 #include <Rcpp.h>
 #include <cstring>
+#include <stdio.h>
 
 // Paul Roebuck has observed that the memory used by an exception message
 // is not reclaimed if error() is called inside of a catch block (due to
@@ -42,8 +43,8 @@ void logTxtFunction(const char* file, const int line, const char* expression) {
 }
 
 SEXP capabilities(){
-	SEXP cap = PROTECT( Rf_allocVector( LGLSXP, 5) ) ;
-	SEXP names = PROTECT( Rf_allocVector( STRSXP, 5 ) ) ;
+	SEXP cap = PROTECT( Rf_allocVector( LGLSXP, 6) ) ;
+	SEXP names = PROTECT( Rf_allocVector( STRSXP, 6 ) ) ;
 #ifdef HAS_VARIADIC_TEMPLATES
 	LOGICAL(cap)[0] = TRUE ;
 #else
@@ -69,11 +70,18 @@ SEXP capabilities(){
 	LOGICAL(cap)[4] = FALSE ;
 #endif
 
+#ifdef RCPP_ENABLE_MODULES
+	LOGICAL(cap)[5] = TRUE ;
+#else
+	LOGICAL(cap)[5] = FALSE ;
+#endif
+
 	SET_STRING_ELT(names, 0, Rf_mkChar("variadic templates") ) ;
 	SET_STRING_ELT(names, 1, Rf_mkChar("initializer lists") ) ;
 	SET_STRING_ELT(names, 2, Rf_mkChar("exception handling") ) ;
 	SET_STRING_ELT(names, 3, Rf_mkChar("tr1 unordered maps") ) ;
 	SET_STRING_ELT(names, 4, Rf_mkChar("tr1 unordered sets") ) ;
+	SET_STRING_ELT(names, 5, Rf_mkChar("Rcpp modules") ) ;
 	Rf_setAttrib( cap, R_NamesSymbol, names ) ;
 	UNPROTECT(2) ;
 	return cap ;
@@ -191,3 +199,9 @@ SEXP RcppXPtrExample_get_external_pointer(SEXP x){
 	return Rf_ScalarInteger( p->back( ) ) ;
 }
 
+SEXP as_character_externalptr(SEXP xp){
+	char buffer[20] ;
+	sprintf( buffer, "%p", EXTPTR_PTR(xp) ) ;
+	return Rcpp::wrap( (const char*)buffer ) ;
+}
+
